==> tropofy-1.4.1.tar.gz: tropofy-1.4.1/tropofy/widgets/download_file_from_url_widget.py <==
'''
Author:      www.tropofy.com

Copyright 2013 Tropofy Pty Ltd, all rights reserved.

This source file is part of Tropofy and govered by the Tropofy terms of service
available at: http://www.tropofy.com/terms_of_service.html

This source file is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
or FITNESS FOR A PARTICULAR PURPOSE. See the license files for details.
'''

from tropofy.widgets.widgets import Widget


class DownloadFileFromUrl(Widget):
    """Displays a download button in the GUI to download custom content.

    The following is a reference of the functions required to define a Export.
    """
    def _get_type(self):
        return "DownloadFileFromUrlWidget"

    def _update(self, request, data, oper, data_set, **kwargs):
        return {'url': self.get_file_url(data_set)}

    def _serialise(self, **kwargs):
        '''Join serialisation dict with Widget to get all params needed on client'''
        return dict(Widget._serialise(self, **kwargs).items() + {
            'buttonText': self.get_export_button_text()
        }.items())

    def get_file_url(self, data_set):
        """The url of the file to be download

        :param data_set: The DataSet object on which queries can be made to access the apps data.
        :type data_set: :class:`tropofy.app.AppDataSet`
        :returns: url
        :rtype: str
        """
        raise NotImplementedError
    
    def get_export_button_text(self):
        """The text on the button in the GUI.

        :rtype: str
        """
        return 'Export'

==> tropofy-1.6.0.tar.gz: tropofy-1.6.0/tropofy/widgets/download_file_from_url_widget.py <==
'''
Author:      www.tropofy.com

Copyright 2013 Tropofy Pty Ltd, all rights reserved.

This source file is part of Tropofy and govered by the Tropofy terms of service
available at: http://www.tropofy.com/terms_of_service.html

This source file is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
or FITNESS FOR A PARTICULAR PURPOSE. See the license files for details.
'''

from tropofy.widgets.widgets import Widget


class DownloadFileFromUrl(Widget):
    """Displays a download button in the GUI to download custom content.

    The following is a reference of the functions required to define a Export.
    """
    def _get_type(self):
        return "DownloadFileFromUrlWidget"

    def _update(self, request, data, oper, data_set, **kwargs):
        return {'url': self.get_file_url(data_set)}

    def _serialise(self, **kwargs):
        '''Join serialisation dict with Widget to get all params needed on client'''
        return dict(Widget._serialise(self, **kwargs).items() + {
            'buttonText': self.get_export_button_text()
        }.items())

    def get_file_url(self, data_set, **kwargs):
        """The url of the file to be download

        :param data_set: The DataSet object on which queries can be made to access the apps data.
        :type data_set: :class:`tropofy.app.AppDataSet`
        :returns: url
        :rtype: str
        """
        raise NotImplementedError
    
    def get_export_button_text(self, **kwargs):
        """The text on the button in the GUI.

        :rtype: str
        """
        return 'Export'
